==> devserv-src-v0.4.3.tar.gz: DEVSERV-V0.4.3/src/canonvcc3.h <==
/* Copyright (c) 1998 Regents of the University of California.
 * rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgment:
 *       This product includes software developed by the Imaging and
 *       Distributed Collaboration Group at Lawrence Berkeley 
 *       National Laboratory.
 * 4. Neither the name of the University nor of the Laboratory may be used
 *    to endorse or promote products derived from this software without
 *    specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * @(#) $Header: canonvcc3.h,v 0.4 98/17/07 16:28:31 mperry Exp $ (LBL)
*/

// canonvcc3.h: Interface for the Canon VC-C3 camera.


#ifndef canonvcc3_h
#define canonvcc3_h

#include <assert.h>
#include "Cam.h"
#include "serialport.h"
#include "utils.h" 

class CanonVCC3 : public Camera {
public:
	CanonVCC3(Serialport *, const char *, int=1, short=1, short=0);
	virtual int move(char *); 
	virtual int doPower();
	virtual int shutDown();
	virtual int goHome();
	virtual void getDesc(char *);
	void setPort(Serialport *);  
private:
	Serialport *portp;
	int transmit(unsigned char *, int);
	int getReply(unsigned char *);
	int readFromCanon(unsigned char *);
	int setCntlMode(const char *);
	int readZoomSpeed();
	int doSoftwareReset();
	void setZoomLimit(); 
	int doPtSpeedCmd();
	int doZoomSpeedCmd();
	int doPanAndTilt();
	int doZoom();
	int convert(const char *, float);
	int calculateChecksum(unsigned char *, int);
	void formatACK(unsigned char *, unsigned char *);
};

#endif

==> devserv-src-v1.1.tar.gz: DEVSERV-V1.1/src/canonvcc3.h <==
/* Copyright (c) 1999 Regents of the University of California.
 * rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgment:
 *       This product includes software developed by the Imaging and
 *       Distributed Collaboratories Group at Lawrence Berkeley 
 *       National Laboratory.
 * 4. Neither the name of the University nor of the Laboratory may be used
 *    to endorse or promote products derived from this software without
 *    specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $Id: canonvcc3.h,v 1.2 1999/07/19 21:10:07 mperry Exp $
*/

// canonvcc3.h: Interface for the Canon VC-C3 camera.


#ifndef canonvcc3_h
#define canonvcc3_h

#include <assert.h>
#include "Cam.h"
#include "serialport.h"

class CanonVCC3 : public Camera {
public:
	CanonVCC3(Serialport *, const char *, int=1, short=1, short=0, Mode=NORMAL);
	virtual int move(char *); 
	virtual int doPower();
	virtual int shutDown();
	virtual int goHome();
	virtual void getDesc(char *);
	void setPort(Serialport *);  
private:
	Serialport *portp;
	void setDefaults();
	int transmit(unsigned char *, int);
	int getReply(unsigned char *);
	int readFromCanon(unsigned char *);
	int setCntlMode(const char *);
	int readZoomSpeed();
	int doSoftwareReset();
	void setZoomLimit(); 
	int doPtSpeedCmd();
	int doZoomSpeedCmd();
	int doPanAndTilt();
	int doZoom();
	int convert(const char *, float);
	int calculateChecksum(unsigned char *, int);
	void formatACK(unsigned char *, unsigned char *);
};

#endif
